==> libosl_0.4.3.orig.tar.gz: libosl_0.4.3.orig/doc/html/search/variables_67.js <==
var searchData=
[
  ['gc_5fratio',['gc_ratio',['../classosl_1_1ntesuki_1_1NtesukiSearcher.html#a0656a8b9cc9d2c3b14f1117fb3617cfc',1,'osl::ntesuki::NtesukiSearcher']]],
  ['gc_5frequest',['gc_request',['../classosl_1_1ntesuki_1_1NtesukiTable_1_1Table.html#ad8a11a92e35d5b364853d43797b9007a',1,'osl::ntesuki::NtesukiTable::Table']]],
  ['gc_5fthreshold',['gc_threshold',['../classosl_1_1checkmate_1_1DfpnTable.html#ace6977a4ece643deed1d14a88c085f22',1,'osl::checkmate::DfpnTable::gc_threshold()'],['../classosl_1_1checkmate_1_1DfpnPathTable.html#a93c12bd143a0f03d8037a6cfc07a45ce',1,'osl::checkmate::DfpnPathTable::gc_threshold()'],['../structosl_1_1checkmate_1_1DualDfpn_1_1Shared.html#ac4ffe158ce9420bc8dbde181872ed3ce',1,'osl::checkmate::DualDfpn::Shared::gc_threshold()']]],
  ['gccount',['gcCount',['../classosl_1_1ntesuki_1_1NtesukiTable_1_1Table.html#acc537d88da466472842861211d1e188a',1,'osl::ntesuki::NtesukiTable::Table']]],
  ['general',['general',['../structosl_1_1move__probability_1_1PinnedGeneral.html#abc3be482332f9e0b0f4e979c62eb45b3',1,'osl::move_probability::PinnedGeneral']]],
  ['generated',['generated',['../structosl_1_1TopProb.html#a0772ad44020dd7492a81520d389a0e0b',1,'osl::TopProb::generated()'],['../structosl_1_1RatingDiffRange.html#a358d48174e07c624a1346aad1abb1a0d',1,'osl::RatingDiffRange::generated()']]],
  ['generated_5fall',['generated_all',['../structosl_1_1TopProb.html#ac1abcf487b3e45131b29be74fda782c3',1,'osl::TopProb']]],
  ['generator',['generator',['../classosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves.html#a6508bdef3f0600358ea4c98c90c8f6a1',1,'osl::game_playing::SpeculativeAllMoves::SearchAllMoves']]],
  ['generatornames',['GeneratorNames',['../classosl_1_1search_1_1MoveGenerator.html#a4c744c8488ed89126a0660820991d78a',1,'osl::search::MoveGenerator']]],
  ['generators',['generators',['../classosl_1_1search_1_1AlphaBeta2Tree.html#aa6d6afd15617b1f93c554606a3698f2b',1,'osl::search::AlphaBeta2Tree::generators()'],['../classosl_1_1search_1_1MoveGenerator.html#a3947a4e8d6700fad57a809cf4707e522',1,'osl::search::MoveGenerator::Generators()']]],
  ['gold',['gold',['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#a218af60f8d7720ef3530d2f0b6076d1b',1,'osl::progress::ml::NewProgressData']]],
  ['gold_5fbonus',['gold_bonus',['../structosl_1_1eval_1_1MinorPieceDebugInfo.html#a0b6ff717db415418712731fa49bef0e6',1,'osl::eval::MinorPieceDebugInfo']]],
  ['gold_5fpenalty',['gold_penalty',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a646c2c5462d7aebbeb1a02a06914a3fd',1,'osl::eval::ProgressDebugInfo']]],
  ['gold_5fpieces',['gold_pieces',['../classosl_1_1record_1_1MiniBoard.html#a2480d9505eed4d6f780579e28b88d22b',1,'osl::record::MiniBoard']]],
  ['golds',['golds',['../classosl_1_1eval_1_1MinorPieceBonus.html#a44286b208c72c2df69549d8c82d6af36',1,'osl::eval::MinorPieceBonus']]],
  ['good_5ftournaments',['good_tournaments',['../csa-to-kisen_8cc.html#a93899444dde2aa2db78eee2873e81a13',1,'csa-to-kisen.cc']]],
  ['green',['Green',['../classosl_1_1record_1_1Color.html#abbda628facf91700dfa16af30ed4dc3b',1,'osl::record::Color']]],
  ['group_5fname',['group_name',['../classosl_1_1rating_1_1Group.html#ab67b9daa3ba5ae45581d52627edb65f7',1,'osl::rating::Group']]],
  ['groups',['groups',['../classosl_1_1rating_1_1FeatureSet.html#a65b66b075675f4432489783a10d5ebbf',1,'osl::rating::FeatureSet']]],
  ['growth_5flimit',['growth_limit',['../classosl_1_1checkmate_1_1DfpnTable.html#af7f86925dca5a4f2c0c007c285ee70ca',1,'osl::checkmate::DfpnTable']]],
  ['growthlimitinfty',['GrowthLimitInfty',['../dfpn_8cc.html#a546febfe92c3257154456169cebc8fa3',1,'dfpn.cc']]],
  ['gs_5fnear_5fking_5fcount',['gs_near_king_count',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#abbb18208f88167ef4003e41449af27fd',1,'osl::eval::ml::OpenMidEndingEval']]]
];

==> libosl_0.6.0.orig.tar.gz: libosl_0.6.0.orig/doc/html/search/variables_67.js <==
var searchData=
[
  ['gc_5fratio',['gc_ratio',['../classosl_1_1ntesuki_1_1NtesukiSearcher.html#a0656a8b9cc9d2c3b14f1117fb3617cfc',1,'osl::ntesuki::NtesukiSearcher']]],
  ['gc_5frequest',['gc_request',['../classosl_1_1ntesuki_1_1NtesukiTable_1_1Table.html#ad8a11a92e35d5b364853d43797b9007a',1,'osl::ntesuki::NtesukiTable::Table']]],
  ['gc_5fthreshold',['gc_threshold',['../classosl_1_1checkmate_1_1DfpnTable.html#ace6977a4ece643deed1d14a88c085f22',1,'osl::checkmate::DfpnTable::gc_threshold()'],['../classosl_1_1checkmate_1_1DfpnPathTable.html#a93c12bd143a0f03d8037a6cfc07a45ce',1,'osl::checkmate::DfpnPathTable::gc_threshold()'],['../structosl_1_1checkmate_1_1DualDfpn_1_1Shared.html#ac4ffe158ce9420bc8dbde181872ed3ce',1,'osl::checkmate::DualDfpn::Shared::gc_threshold()']]],
  ['gccount',['gcCount',['../classosl_1_1ntesuki_1_1NtesukiTable_1_1Table.html#acc537d88da466472842861211d1e188a',1,'osl::ntesuki::NtesukiTable::Table']]],
  ['general',['general',['../structosl_1_1move__probability_1_1PinnedGeneral.html#abc3be482332f9e0b0f4e979c62eb45b3',1,'osl::move_probability::PinnedGeneral']]],
  ['generated',['generated',['../structosl_1_1TopProb.html#a0772ad44020dd7492a81520d389a0e0b',1,'osl::TopProb::generated()'],['../structosl_1_1RatingDiffRange.html#a358d48174e07c624a1346aad1abb1a0d',1,'osl::RatingDiffRange::generated()']]],
  ['generated_5fall',['generated_all',['../structosl_1_1TopProb.html#ac1abcf487b3e45131b29be74fda782c3',1,'osl::TopProb']]],
  ['generator',['generator',['../classosl_1_1game__playing_1_1SpeculativeAllMoves_1_1SearchAllMoves.html#a6508bdef3f0600358ea4c98c90c8f6a1',1,'osl::game_playing::SpeculativeAllMoves::SearchAllMoves']]],
  ['generatornames',['GeneratorNames',['../classosl_1_1search_1_1MoveGenerator.html#a4c744c8488ed89126a0660820991d78a',1,'osl::search::MoveGenerator']]],
  ['generators',['generators',['../classosl_1_1search_1_1AlphaBeta2Tree.html#aa6d6afd15617b1f93c554606a3698f2b',1,'osl::search::AlphaBeta2Tree::generators()'],['../classosl_1_1search_1_1MoveGenerator.html#a3947a4e8d6700fad57a809cf4707e522',1,'osl::search::MoveGenerator::Generators()']]],
  ['gold',['gold',['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#a218af60f8d7720ef3530d2f0b6076d1b',1,'osl::progress::ml::NewProgressData']]],
  ['gold_5fbonus',['gold_bonus',['../structosl_1_1eval_1_1MinorPieceDebugInfo.html#a0b6ff717db415418712731fa49bef0e6',1,'osl::eval::MinorPieceDebugInfo']]],
  ['gold_5fpenalty',['gold_penalty',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a646c2c5462d7aebbeb1a02a06914a3fd',1,'osl::eval::ProgressDebugInfo']]],
  ['gold_5fpieces',['gold_pieces',['../classosl_1_1record_1_1MiniBoard.html#a2480d9505eed4d6f780579e28b88d22b',1,'osl::record::MiniBoard']]],
  ['golds',['golds',['../classosl_1_1eval_1_1MinorPieceBonus.html#a44286b208c72c2df69549d8c82d6af36',1,'osl::eval::MinorPieceBonus']]],
  ['good_5ftournaments',['good_tournaments',['../csa-to-kisen_8cc.html#a93899444dde2aa2db78eee2873e81a13',1,'csa-to-kisen.cc']]],
  ['gradient',['gradient',['../learn-piece_8cc.html#a4d9a08ef6c751e1d420ce8301e39b12a',1,'learn-piece.cc']]],
  ['green',['Green',['../classosl_1_1record_1_1Color.html#abbda628facf91700dfa16af30ed4dc3b',1,'osl::record::Color']]],
  ['group_5fname',['group_name',['../classosl_1_1rating_1_1Group.html#ab67b9daa3ba5ae45581d52627edb65f7',1,'osl::rating::Group']]],
  ['groups',['groups',['../classosl_1_1rating_1_1FeatureSet.html#a65b66b075675f4432489783a10d5ebbf',1,'osl::rating::FeatureSet']]],
  ['growth_5flimit',['growth_limit',['../classosl_1_1checkmate_1_1DfpnTable.html#af7f86925dca5a4f2c0c007c285ee70ca',1,'osl::checkmate::DfpnTable']]],
  ['growthlimitinfty',['GrowthLimitInfty',['../dfpn_8cc.html#a546febfe92c3257154456169cebc8fa3',1,'dfpn.cc']]],
  ['gs_5fnear_5fking_5fcount',['gs_near_king_count',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#abbb18208f88167ef4003e41449af27fd',1,'osl::eval::ml::OpenMidEndingEval']]]
];
